==> mm3d_1.3.12.orig.tar.gz: mm3d-1.3.12/src/implui/mview.h <==
/*  Maverick Model 3D
 * 
 *  Copyright (c) 2004-2007 Kevin Worcester
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
 *  USA.
 *
 *  See the COPYING file for full license text.
 */


#ifndef __MVIEW_H
#define __MVIEW_H

#include "modelview.base.h"
#include "modelviewport.h"

#include <QtWidgets/QWidget>

class Model;
class Toolbox;
class Texture;

class ModelView : public QWidget, public Ui::ModelViewBase
{
      Q_OBJECT

   public:

      ModelView( Toolbox * toolbox, QWidget * parent = NULL );
      virtual ~ModelView();

      void freeTextures();
      void setModel( Model * model );
      void frameArea( double x1, double y1, double z1, double x2, double y2, double z2 ) { m_modelView->frameArea( x1, y1, z1, x2, y2, z2 ); };
      void updateView();

      unsigned getViewDirection();
      QString getViewDirectionLabel();
      void copyContentsToTexture( Texture * tex );
      void updateCaptureGL();
      QImage grabFrameBuffer( bool withAlpha );

      ModelViewport * getModelViewport() { return m_modelView; };

   public slots:

      void setViewDirection( int dir );
      void zoomLevelEnterEvent();

      void zoomInEvent();
      void zoomOutEvent();

   protected:

      Toolbox * m_toolbox;
};


#endif // __MVIEW_H

==> mm3d_1.3.15.orig.tar.gz: mm3d-1.3.15/src/implui/mview.h <==
/*  Maverick Model 3D
 * 
 *  Copyright (c) 2004-2007 Kevin Worcester
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, 
 *  USA.
 *
 *  See the COPYING file for full license text.
 */


#ifndef __MVIEW_H
#define __MVIEW_H

#include "modelview.base.h"
#include "modelviewport.h"

#include <QtWidgets/QWidget>

class Model;
class Toolbox;
class Texture;

class ModelView : public QWidget, public Ui::ModelViewBase
{
      Q_OBJECT

   public:

      ModelView( Toolbox * toolbox, QWidget * parent = NULL );
      virtual ~ModelView();

      void freeTextures();
      void setModel( Model * model );
      void frameArea( double x1, double y1, double z1, double x2, double y2, double z2 ) { m_modelView->frameArea( x1, y1, z1, x2, y2, z2 ); };
      void updateView();

      unsigned getViewDirection();
      QString getViewDirectionLabel();
      void copyContentsToTexture( Texture * tex );
      void updateCaptureGL();
      QImage grabFramebuffer();

      ModelViewport * getModelViewport() { return m_modelView; };

   public slots:

      void setViewDirection( int dir );
      void zoomLevelEnterEvent();

      void zoomInEvent();
      void zoomOutEvent();

   protected:

      Toolbox * m_toolbox;
};


#endif // __MVIEW_H
